@@ -20,7 +20,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kdecompat.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 // ----------------------------------------------------------------------------
 // QT Includes
@@ -36,15 +38,15 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kcompletionbox.h>
+#include <tdemessagebox.h>
+#include <tdecompletionbox.h>
 #include <kpushbutton.h>
-#include <kpopupmenu.h>
-#include <kstdaccel.h>
-#include <kshortcut.h>
+#include <tdepopupmenu.h>
+#include <tdestdaccel.h>
+#include <tdeshortcut.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -93,12 +95,12 @@ kMyMoneySplitTable::kMyMoneySplitTable(TQWidget *parent, const char *name ) :
   setHScrollBarMode(TQScrollView::AlwaysOff);
 
   // setup the context menu
-  m_contextMenu = new KPopupMenu(this);
-  KIconLoader *il = KGlobal::iconLoader();
-  m_contextMenu->insertTitle(il->loadIcon("transaction", KIcon::MainToolbar), i18n("Split Options"));
-  m_contextMenu->insertItem(il->loadIcon("edit", KIcon::Small), i18n("Edit..."), this, TQT_SLOT(slotStartEdit()));
-  m_contextMenuDuplicate = m_contextMenu->insertItem(il->loadIcon("editcopy", KIcon::Small), i18n("Duplicate"), this, TQT_SLOT(slotDuplicateSplit()));
-  m_contextMenuDelete = m_contextMenu->insertItem(il->loadIcon("delete", KIcon::Small),
+  m_contextMenu = new TDEPopupMenu(this);
+  TDEIconLoader *il = TDEGlobal::iconLoader();
+  m_contextMenu->insertTitle(il->loadIcon("transaction", TDEIcon::MainToolbar), i18n("Split Options"));
+  m_contextMenu->insertItem(il->loadIcon("edit", TDEIcon::Small), i18n("Edit..."), this, TQT_SLOT(slotStartEdit()));
+  m_contextMenuDuplicate = m_contextMenu->insertItem(il->loadIcon("edit-copy", TDEIcon::Small), i18n("Duplicate"), this, TQT_SLOT(slotDuplicateSplit()));
+  m_contextMenuDelete = m_contextMenu->insertItem(il->loadIcon("delete", TDEIcon::Small),
                         i18n("Delete ..."),
                         this, TQT_SLOT(slotDeleteSplit()));
 
@@ -272,8 +274,8 @@ bool kMyMoneySplitTable::eventFilter(TQObject *o, TQEvent *e)
 
       default:
         rc = true;
-        KShortcut copySplit(i18n("Duplicate split", "CTRL+c"));
-        KShortcut newSplit(TQKeySequence(TQt::CTRL | TQt::Key_Insert));
+        TDEShortcut copySplit(i18n("Duplicate split", "CTRL+c"));
+        TDEShortcut newSplit(TQKeySequence(TQt::CTRL | TQt::Key_Insert));
         if(copySplit.contains(KKey(k))) {
           slotDuplicateSplit();
 
@@ -312,7 +314,7 @@ bool kMyMoneySplitTable::eventFilter(TQObject *o, TQEvent *e)
         // do not end editing of the transaction.
         if(o->inherits("KLineEdit")) {
           KLineEdit* le = dynamic_cast<KLineEdit*> (o);
-          KCompletionBox* box = le->completionBox(false);
+          TDECompletionBox* box = le->completionBox(false);
           if(box && box->isVisible()) {
             terminate = false;
             le->completionBox(false)->hide();
@@ -554,7 +556,7 @@ void kMyMoneySplitTable::slotUpdateData(const MyMoneyTransaction& t)
       try {
         colText = MyMoneyFile::instance()->accountToCategory((*it).accountId());
       } catch(MyMoneyException *e) {
-        qDebug("Unexpected exception in kMyMoneySplitTable::slotUpdateData()");
+        tqDebug("Unexpected exception in kMyMoneySplitTable::slotUpdateData()");
         delete e;
       }
     }
@@ -636,7 +638,7 @@ void kMyMoneySplitTable::slotDuplicateSplit(void)
       m_transaction.addSplit(split);
       emit transactionChanged(m_transaction);
     } catch(MyMoneyException *e) {
-      qDebug("Cannot duplicate split: %s", e->what().latin1());
+      tqDebug("Cannot duplicate split: %s", e->what().latin1());
       delete e;
     }
   }
@@ -662,7 +664,7 @@ void kMyMoneySplitTable::slotDeleteSplit(void)
           setCurrentCell(m_currentRow, 0);
         emit transactionChanged(m_transaction);
       } catch(MyMoneyException *e) {
-        qDebug("Cannot remove split: %s", e->what().latin1());
+        tqDebug("Cannot remove split: %s", e->what().latin1());
         delete e;
       }
     }
@@ -781,7 +783,7 @@ void kMyMoneySplitTable::endEdit(bool keyBoardDriven)
       }
       emit transactionChanged(m_transaction);
     } catch(MyMoneyException *e) {
-      qDebug("Cannot add/modify split: %s", e->what().latin1());
+      tqDebug("Cannot add/modify split: %s", e->what().latin1());
       delete e;
     }
   }
@@ -851,16 +853,16 @@ TQWidget* kMyMoneySplitTable::createEditWidgets(void)
   m_editMemo->setFont(cellFont);
 
   // create buttons for the mouse users
-  KIconLoader *il = KGlobal::iconLoader();
+  TDEIconLoader *il = TDEGlobal::iconLoader();
   m_registerButtonFrame = new TQFrame(this, "buttonFrame");
   TQPalette palette = m_registerButtonFrame->palette();
   palette.setColor(TQColorGroup::Background, rowBackgroundColor(m_currentRow+1) );
   m_registerButtonFrame->setPalette(palette);
 
   TQHBoxLayout* l = new TQHBoxLayout(m_registerButtonFrame);
-  m_registerEnterButton = new KPushButton(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall), TQString(), m_registerButtonFrame, "EnterButton");
+  m_registerEnterButton = new KPushButton(il->loadIcon("button_ok", TDEIcon::Small, TDEIcon::SizeSmall), TQString(), m_registerButtonFrame, "EnterButton");
 
-  m_registerCancelButton = new KPushButton(il->loadIcon("button_cancel", KIcon::Small, KIcon::SizeSmall), TQString(), m_registerButtonFrame, "CancelButton");
+  m_registerCancelButton = new KPushButton(il->loadIcon("button_cancel", TDEIcon::Small, TDEIcon::SizeSmall), TQString(), m_registerButtonFrame, "CancelButton");
 
   l->addWidget(m_registerEnterButton);
   l->addWidget(m_registerCancelButton);
