@@ -17,10 +17,6 @@
 #ifndef MYMONEYFILE_H
 #define MYMONEYFILE_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
