@@ -12,7 +12,7 @@
  ***************************************************************************/
 
  /****************************************************************************
- Contains code from the KDateTable class ala kdelibs-3.1.2.  Original license:
+ Contains code from the KDateTable class ala tdelibs-3.1.2.  Original license:
 
     This file is part of the KDE libraries
     Copyright (C) 1997 Tim D. Gilman (tdgilman@best.org)
@@ -42,6 +42,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 #include <tqglobal.h>
@@ -53,12 +57,12 @@
 
 // ----------------------------------------------------------------------------
 // KDE Includes
-#include "kdecompat.h"
+#include <tdeversion.h>
 #include <kdatetbl.h> // Use the classes available for maximum re-use
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <knotifyclient.h>
 #if KDE_IS_VERSION(3,2,0)
@@ -85,7 +89,7 @@ kMyMoneyDateTbl::kMyMoneyDateTbl(TQWidget *parent, TQDate date_, const char* nam
   setFocusPolicy( TQ_StrongFocus );
 
 
-  viewport()->setEraseColor(KGlobalSettings::baseColor());
+  viewport()->setEraseColor(TDEGlobalSettings::baseColor());
 
   setDate(date_); // this initializes firstday, numdays, numDaysPrevMonth
 
@@ -102,17 +106,17 @@ kMyMoneyDateTbl::paintCell(TQPainter *painter, int row, int col)
   TQPen pen;
   int w=cellWidth();
   int h=cellHeight();
-  TQBrush brushBlue(KGlobalSettings::activeTitleColor());
-  TQBrush brushLightblue(KGlobalSettings::baseColor());
-  TQFont font=KGlobalSettings::generalFont();
+  TQBrush brushBlue(TDEGlobalSettings::activeTitleColor());
+  TQBrush brushLightblue(TDEGlobalSettings::baseColor());
+  TQFont font=TDEGlobalSettings::generalFont();
 
   // -----
   font.setPointSize(fontsize);
 
-#if KDE_VERSION < 310
-  int firstWeekDay = KGlobal::locale()->weekStartsMonday() ? 1 : 0;
+#if TDE_VERSION < 310
+  int firstWeekDay = TDEGlobal::locale()->weekStartsMonday() ? 1 : 0;
 #else
-  int firstWeekDay = KGlobal::locale()->weekStartDay();
+  int firstWeekDay = TDEGlobal::locale()->weekStartDay();
 #endif
 
   if (row==0)
@@ -133,19 +137,19 @@ kMyMoneyDateTbl::paintCell(TQPainter *painter, int row, int col)
 
       if (!normalday)
       {
-        painter->setPen(KGlobalSettings::baseColor());
+        painter->setPen(TDEGlobalSettings::baseColor());
         painter->setBrush(brushLightblue);
         painter->drawRect(0, 0, w, h);
-        painter->setPen(KGlobalSettings::activeTitleColor());
+        painter->setPen(TDEGlobalSettings::activeTitleColor());
       } else {
-        painter->setPen(KGlobalSettings::activeTitleColor());
+        painter->setPen(TDEGlobalSettings::activeTitleColor());
         painter->setBrush(brushBlue);
         painter->drawRect(0, 0, w, h);
-        painter->setPen(KGlobalSettings::activeTextColor());
+        painter->setPen(TDEGlobalSettings::activeTextColor());
       }
       painter->drawText(0, 0, w, h-1, AlignCenter,
                         daystr, -1, &rect);
-      painter->setPen(KGlobalSettings::textColor());
+      painter->setPen(TDEGlobalSettings::textColor());
       painter->moveTo(0, h-1);
       painter->lineTo(w-1, h-1);
 
@@ -157,10 +161,10 @@ kMyMoneyDateTbl::paintCell(TQPainter *painter, int row, int col)
     }
     else if (m_type == WEEKLY)
     {
-      painter->setPen(KGlobalSettings::activeTitleColor());
+      painter->setPen(TDEGlobalSettings::activeTitleColor());
       painter->setBrush(brushBlue);
       painter->drawRect(0, 0, w, h);
-      painter->setPen(KGlobalSettings::activeTextColor());
+      painter->setPen(TDEGlobalSettings::activeTextColor());
 
       int year=date.year();
       TQString headerText;
@@ -182,9 +186,9 @@ kMyMoneyDateTbl::paintCell(TQPainter *painter, int row, int col)
     {
       int athird = width()/3;
 
-      painter->setPen(KGlobalSettings::activeTitleColor());
+      painter->setPen(TDEGlobalSettings::activeTitleColor());
       painter->setBrush(brushBlue);
-      painter->setPen(/*KGlobalSettings::activeTextColor()*/black);
+      painter->setPen(/*TDEGlobalSettings::activeTextColor()*/black);
 
       if (col == 0)
       {
@@ -378,10 +382,10 @@ kMyMoneyDateTbl::contentsMouseReleaseEvent(TQMouseEvent *e)
     return;
   }
 
-#if KDE_VERSION < 310
-  int dayoff = KGlobal::locale()->weekStartsMonday() ? 1 : 0;
+#if TDE_VERSION < 310
+  int dayoff = TDEGlobal::locale()->weekStartsMonday() ? 1 : 0;
 #else
-  int dayoff = KGlobal::locale()->weekStartDay();
+  int dayoff = TDEGlobal::locale()->weekStartDay();
 #endif
 
   // -----
@@ -571,10 +575,10 @@ void kMyMoneyDateTbl::contentsMouseMoveEvent(TQMouseEvent* e)
     return;
   }
 
-#if KDE_VERSION < 310
-  int firstWeekDay = KGlobal::locale()->weekStartsMonday() ? 1 : 0;
+#if TDE_VERSION < 310
+  int firstWeekDay = TDEGlobal::locale()->weekStartsMonday() ? 1 : 0;
 #else
-  int firstWeekDay = KGlobal::locale()->weekStartDay();
+  int firstWeekDay = TDEGlobal::locale()->weekStartDay();
 #endif
 
   TQDate drawDate(date);
