@@ -19,8 +19,6 @@
 #include <config.h>
 #endif
 
-#include "kdecompat.h"
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -58,7 +56,7 @@ public:
 };
 
 extern "C" {
-    void *init_libkgpgfile()
+    KDE_EXPORT void *init_libkgpgfile()
     {
         return new KGPGFileFactory;
     }
@@ -572,7 +570,7 @@ void KGPGFile::publicKeyList(TQStringList& list, const TQString& pattern)
         val = TQString("%1:%2").arg(currentKey).arg(fields[9]);
         map[val] = val;
       } else {
-        tqDebug("'%s' is expired", fields[9].data());
+        tqDebug(TQString("'%1' is expired").arg(fields[9]));
       }
     } else if(fields[0] == "uid") {
       val = TQString("%1:%2").arg(currentKey).arg(fields[9]);
